==> fourpaypayments-0.0.1.tar.gz: lib/fourpaypayments.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:flutter/services.dart';
import 'flutter_apple_pay.dart' as ApplePay;

import 'flutter_google_pay.dart';

class PaymentResult {
  String errorText;
  bool get hasError => (errorText ?? "").isNotEmpty;
  String response;

  @override
  String toString() {
  return 'PaymentResult:\n' + (hasError ? '\tError: $errorText' : '\tReponse: $response');
   }
}

class FourPayPayments {
  static Future<PaymentResult> makeApplePayment(
    String authToken,
    String merchantId, {
    String label,
    String description,
    String txid,
    double amount,
  }) async {
    dynamic paymentTokenInfo;
    ApplePay.PaymentItem paymentItems =
        ApplePay.PaymentItem(label: label, amount: amount);
    try {
      var canMakePayment = await ApplePay.FlutterApplePay.canMakePayments();
      if (canMakePayment) {
        paymentTokenInfo = await ApplePay.FlutterApplePay.getPaymentToken(
          countryCode: "RU",
          currencyCode: "RUB",
          paymentNetworks: [
            ApplePay.PaymentNetwork.visa,
            ApplePay.PaymentNetwork.mastercard
          ],
          merchantIdentifier: merchantId,
          paymentItems: [paymentItems],
        );
        Map<String, dynamic> paymentInfo = Map.from(paymentTokenInfo);
        String paymentToken = paymentInfo["pk_token"];
        String base64token = _convertToBase64(paymentToken);
        PaymentResult result = await _proceedPay(authToken, amount, description, txid, base64token);
        ApplePay.FlutterApplePay.closeApplePaySheet(isSuccess: !result.hasError);
        return result;
      } else {
        ApplePay.FlutterApplePay.closeApplePaySheet(isSuccess: false);
        return PaymentResult()
          ..errorText = 'нет возможности использовать ApplePay';
      }
    } on PlatformException {
      ApplePay.FlutterApplePay.closeApplePaySheet(isSuccess: false);
      return PaymentResult()..errorText = 'Ошибка оплаты через ApplePay';
    } catch (e) {
      ApplePay.FlutterApplePay.closeApplePaySheet(isSuccess: false);
      return PaymentResult()..errorText = 'Ошибка оплаты через ApplePay: $e';
    }
  }

  static Future<PaymentResult> makeGooglePayment(
    String authToken,
    String merchantId, {
    String gateway = "themap",
    String merchantInfo,
    String description,
    String txid,
    double amount,
    String environment = 'production',
  }) async {
    bool isAvailable = await FlutterGooglePay.isAvailable(environment);
    if (!isAvailable) {
      return PaymentResult()..errorText = 'Google pay not available';
    } else {
      PaymentBuilder pb = PaymentBuilder()
        ..addGateway(gateway, gatewayMerchantId: merchantId)
        ..addShippingSupportedCountries(["RU"])
        ..addTransactionInfo("$amount", "RUB", "RU")
        ..addAllowedCardAuthMethods(
            [AuthMethod.PAN_ONLY, AuthMethod.CRYPTOGRAM_3DS])
        ..addAllowedCardNetworks(
            [PaymentNetwork.MASTERCARD, PaymentNetwork.VISA])
        ..addMerchantInfo(merchantInfo);

      Result result = await FlutterGooglePay.makeCustomPayment(pb.build());
      if (result.status == ResultStatus.SUCCESS) {
        String paymentToken = result.data['paymentMethodData']['tokenizationData']['token'];
        String base64Token = _convertToBase64(paymentToken);
        return _proceedPay(authToken, amount, description, txid, base64Token);
      } else {
        return PaymentResult()
          ..errorText = "result.error != null ${result.error}";
      }
    }
  }

  static String _convertToBase64(String source) {
    var utf8EncodedString = utf8.encode(source);
    var base64EncodedString = base64.encode(utf8EncodedString);
    return base64EncodedString;
  }

  static Future<PaymentResult> _proceedPay(
    String authToken,
    double amount,
    String description,
    String txid,
    String base64Token,
  ) async {
    var response = await Dio(BaseOptions(
      baseUrl: 'https://4pay.online',
      headers: {'Authorization': 'Bearer $authToken'},
    )).post(
      '/api/v1/payments',
      queryParameters: {
        "payment": {
          "amount": (amount * 100).toInt().toString(),
          "type": Platform.isIOS ? "apple_pay" : "google_pay",
          "money_storage": {
            Platform.isIOS ? "apple_pay_token" : "google_pay_token": base64Token
          },
          "description": description,
          "txid": txid
        }
      },
    );
    if (response.statusCode != 200) {
      return PaymentResult()..errorText = "${response.data}";
    }
    print("$response");
    return PaymentResult()..response = "${response.data}";
  }
}

==> fourpaypayments-0.1.1.tar.gz: lib/fourpaypayments.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:flutter/services.dart';
import 'flutter_apple_pay.dart' as ApplePay;

import 'flutter_google_pay.dart';

class PaymentResult {
  String errorText;
  bool get hasError => (errorText ?? "").isNotEmpty;
  String response;

  @override
  String toString() {
    return 'PaymentResult:\n' +
        (hasError ? '\tError: $errorText' : '\tReponse: $response');
  }
}

class FourPayPayments {
  static Future<PaymentResult> makeApplePayment(
    String authToken,
    String merchantId, {
    String label,
    String description,
    String txid,
    double amount,
  }) async {
    dynamic paymentTokenInfo;
    ApplePay.PaymentItem paymentItems =
        ApplePay.PaymentItem(label: label, amount: amount);
    try {
      var canMakePayment = await ApplePay.FlutterApplePay.canMakePayments();
      if (canMakePayment) {
        paymentTokenInfo = await ApplePay.FlutterApplePay.getPaymentToken(
          countryCode: "RU",
          currencyCode: "RUB",
          paymentNetworks: [
            ApplePay.PaymentNetwork.visa,
            ApplePay.PaymentNetwork.mastercard
          ],
          merchantIdentifier: merchantId,
          paymentItems: [paymentItems],
        );
        Map<String, dynamic> paymentInfo = Map.from(paymentTokenInfo);
        String paymentToken = paymentInfo["pk_token"];
        String base64token = _convertToBase64(paymentToken);
        PaymentResult result = await _proceedPay(
            authToken, amount, description, txid, base64token);
        ApplePay.FlutterApplePay.closeApplePaySheet(
            isSuccess: !result.hasError);
        return result;
      } else {
        ApplePay.FlutterApplePay.closeApplePaySheet(isSuccess: false);
        return PaymentResult()
          ..errorText = 'нет возможности использовать ApplePay';
      }
    } on PlatformException {
      ApplePay.FlutterApplePay.closeApplePaySheet(isSuccess: false);
      return PaymentResult()..errorText = 'Ошибка оплаты через ApplePay';
    } catch (e) {
      ApplePay.FlutterApplePay.closeApplePaySheet(isSuccess: false);
      return PaymentResult()..errorText = 'Ошибка оплаты через ApplePay: $e';
    }
  }

  static Future<PaymentResult> makeGooglePayment(
    String authToken,
    String merchantId, {
    String gateway = "themap",
    String merchantInfo,
    String description,
    String txid,
    double amount,
    String environment = 'production',
  }) async {
    bool isAvailable = await FlutterGooglePay.isAvailable(environment);
    if (!isAvailable) {
      return PaymentResult()..errorText = 'Google pay not available';
    } else {
      PaymentBuilder pb = PaymentBuilder()
        ..addGateway(gateway, gatewayMerchantId: merchantId)
        ..addShippingSupportedCountries(["RU"])
        ..addTransactionInfo("$amount", "RUB", "RU")
        ..addAllowedCardAuthMethods(
            [AuthMethod.PAN_ONLY, AuthMethod.CRYPTOGRAM_3DS])
        ..addAllowedCardNetworks(
            [PaymentNetwork.MASTERCARD, PaymentNetwork.VISA])
        ..addMerchantInfo(merchantInfo);

      Result result = await FlutterGooglePay.makeCustomPayment(pb.build());
      if (result.status == ResultStatus.SUCCESS) {
        String paymentToken =
            result.data['paymentMethodData']['tokenizationData']['token'];
        String base64Token = _convertToBase64(paymentToken);
        return _proceedPay(authToken, amount, description, txid, base64Token);
      } else {
        return PaymentResult()
          ..errorText = "result.error != null ${result.error}";
      }
    }
  }

  static String _convertToBase64(String source) {
    var utf8EncodedString = utf8.encode(source);
    var base64EncodedString = base64.encode(utf8EncodedString);
    return base64EncodedString;
  }

  static Future<PaymentResult> _proceedPay(
    String authToken,
    double amount,
    String description,
    String txid,
    String base64Token,
  ) async {
    var response = await Dio(BaseOptions(
      baseUrl: 'https://4pay.online',
      headers: {'Authorization': 'Bearer $authToken'},
    )).post(
      '/api/v1/payments',
      queryParameters: {
        "payment": {
          "amount": (amount * 100).toInt().toString(),
          "type": Platform.isIOS ? "apple_pay" : "google_pay",
          "money_storage": {
            Platform.isIOS ? "apple_pay_token" : "google_pay_token": base64Token
          },
          "description": description,
          "txid": txid
        }
      },
    );
    if (response.statusCode != 200) {
      return PaymentResult()..errorText = "${response.data}";
    }
    print("$response");
    return PaymentResult()..response = "${response.data}";
  }
}
